@@ -112,9 +112,9 @@ class Connect:
         """
 
         read = self.read_line(do_check)
+        # self.ser.flushInput()
         if read is not None:
-            tmp = read.decode().split(',')
-
+            tmp = read.decode("utf-8").split(',')
             if len(tmp) == self.connections:
                 return list(map(float, tmp))
             else:
@@ -138,7 +138,7 @@ class Connect:
         """
 
         if self.data_method == 'com':
-            self.ser.flush()
+            self.ser.flushInput()
         else:
             raise Exception("This function flush is not available for this data_method")
 
